@@ -10,9 +10,7 @@
 #include "incidencechanger.h"
 #include "utils_p.h"
 #include "akonadicalendar_debug.h"
-#include <item.h>
 #include <collectionfetchjob.h>
-#include <collection.h>
 
 #include <KLocalizedString>
 #include <QTimeZone>
@@ -38,9 +36,6 @@ static QString itemToString(const Akonadi::Item &item)
 CalendarBasePrivate::CalendarBasePrivate(CalendarBase *qq)
     : QObject()
     , mIncidenceChanger(new IncidenceChanger())
-    , mBatchInsertionCancelled(false)
-    , mListensForNewItems(false)
-    , mLastCreationCancelled(false)
     , q(qq)
 {
     connect(mIncidenceChanger, &IncidenceChanger::createFinished,
@@ -118,7 +113,7 @@ void CalendarBasePrivate::internalInsert(const Akonadi::Item &item)
                 incidence->setReadOnly(!(collection.rights() & Akonadi::Collection::CanChangeItem));
             } else if (!mCollectionJobs.key(item.storageCollectionId())) {
                 collection = Akonadi::Collection(item.storageCollectionId());
-                Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(collection, Akonadi::CollectionFetchJob::Base, this);
+                auto *job = new Akonadi::CollectionFetchJob(collection, Akonadi::CollectionFetchJob::Base, this);
                 QObject::connect(job, &KJob::result, this, &CalendarBasePrivate::collectionFetchResult);
                 mCollectionJobs.insert(job, collection.id());
             }
@@ -159,7 +154,7 @@ void CalendarBasePrivate::collectionFetchResult(KJob *job)
         return;
     }
 
-    Akonadi::CollectionFetchJob *fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
 
     const Akonadi::Collection collection = fetchJob->collections().at(0);
     if (collection.id() != colid) {
