@@ -9,7 +9,6 @@
 #include "fetchjobcalendar_p.h"
 #include "incidencefetchjob_p.h"
 #include "akonadicalendar_debug.h"
-#include <item.h>
 #include <collection.h>
 
 using namespace Akonadi;
@@ -17,10 +16,9 @@ using namespace KCalendarCore;
 
 FetchJobCalendarPrivate::FetchJobCalendarPrivate(FetchJobCalendar *qq)
     : CalendarBasePrivate(qq)
-    , m_isLoaded(false)
     , q(qq)
 {
-    IncidenceFetchJob *job = new IncidenceFetchJob();
+    auto *job = new IncidenceFetchJob();
     connect(job, &KJob::result,
             this, &FetchJobCalendarPrivate::slotSearchJobFinished);
     connect(this, &CalendarBasePrivate::fetchFinished,
@@ -33,7 +31,7 @@ FetchJobCalendarPrivate::~FetchJobCalendarPrivate()
 
 void FetchJobCalendarPrivate::slotSearchJobFinished(KJob *job)
 {
-    IncidenceFetchJob *searchJob = static_cast<Akonadi::IncidenceFetchJob *>(job);
+    auto *searchJob = static_cast<Akonadi::IncidenceFetchJob *>(job);
     m_success = true;
     m_errorMessage = QString();
     if (searchJob->error()) {
@@ -77,7 +75,7 @@ FetchJobCalendar::~FetchJobCalendar()
 
 bool FetchJobCalendar::isLoaded() const
 {
-    FetchJobCalendarPrivate *d = static_cast<FetchJobCalendarPrivate *>(d_ptr.data());
+    auto *d = static_cast<FetchJobCalendarPrivate *>(d_ptr.data());
     return d->m_isLoaded;
 }
 
