@@ -11,7 +11,6 @@
 
 #include "publishdialog_p.h"
 
-#include <KCalendarCore/Attendee>
 #include <KCalendarCore/Person>
 
 #include <KCodecs/KEmailAddress>
@@ -32,7 +31,7 @@ PublishDialog::PublishDialog(QWidget *parent)
     , d(new Private(this))
 {
     setWindowTitle(i18nc("@title:window", "Select Addresses"));
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     QWidget *widget = new QWidget(this);
     widget->setObjectName(QStringLiteral("PublishFreeBusy"));
     d->mUI.setupUi(widget);
@@ -100,7 +99,7 @@ void PublishDialog::addAttendee(const Attendee &attendee)
 {
     d->mUI.mNameLineEdit->setEnabled(true);
     d->mUI.mEmailLineEdit->setEnabled(true);
-    QListWidgetItem *item = new QListWidgetItem(d->mUI.mListWidget);
+    auto *item = new QListWidgetItem(d->mUI.mListWidget);
     Person person(attendee.name(), attendee.email());
     item->setText(person.fullName());
     d->mUI.mListWidget->addItem(item);
